import { Module } from '@nestjs/common';
import { AppController } from './app.controller';
import { AppService } from './app.service';
import { NovuModule } from '@novu/framework/nest';
import LogHelp from '@dt/log-help';
import { ClsModule, ClsService } from 'nestjs-cls';
import { v4 as uuidv4 } from 'uuid';
import { LoggingInterceptor } from './common/interceptor/logging.interceptor';
import { LoggerService } from './common/service/logger.service';
import { Request } from 'express';
import * as novuWorkflows from './novu/index';

@Module({
  imports: [
    NovuModule.register({
      apiPath: '/api/novu',
      workflows: [...Object.values(novuWorkflows)],
    }),
    ClsModule.forRoot({
      global: true,
      middleware: {
        mount: true,
        setup: (cls: ClsService, req: Request) => {
          const url = req.headers['url'] as string | undefined;
          cls.set('url', url || '');

          const dtlog = new LogHelp();
          dtlog.set({ url: cls.get('url') });

          let traceId = req.headers['trace_id'] as string | undefined;

          if (!traceId) {
            traceId = uuidv4().replace(/-/g, '');
            req.headers['trace_id'] = traceId;
          }

          dtlog.set({ trace_id: traceId });
          cls.set('dtlog', dtlog);
        },
      },
    }),
  ],
  controllers: [AppController],
  providers: [AppService, LoggingInterceptor, LoggerService],
})
export class AppModule {}
