import { workflow } from '@novu/framework';
import { z } from 'zod';

const payloadSchema = z.object({
  brand: z.string().describe('品牌'),
  store: z.string().describe('门店'),
  items: z.string().describe('停售餐品'),
  storeId: z.string().describe('门店ID'),
  deviceToken: z.string().describe('设备令牌').optional(),
});

export const autoStopSaleWorkflow = workflow(
  'auto-stop-sale-workflow',
  async ({ step, payload }) => {
    // 发送站内通知
    await step.inApp(
      'send-auto-stop-sale-notification',
      () => {
        return {
          subject: '自动停售提醒',
          body: `【${payload.brand}-${payload.store}】"${payload.items}"等餐品已自动停售，点击查看详情。`,
          primaryAction: {
            label: '查看详情',
          },
          data: {
            link: `/store/${payload.storeId}/items/status`,
          },
        };
      },
      {
        controlSchema: z.object({
          content: z.string().default('自动停售提醒通知'),
        }),
      },
    );

    // 发送 App Push 通知
    await step.push(
      'send-auto-stop-sale-push',
      () => {
        return {
          subject: '自动停售提醒',
          body: `【${payload.brand}-${payload.store}】${payload.items}等餐品已自动停售`,
        };
      },
      {
        skip: () => !payload.deviceToken,
      },
    );
  },
  {
    payloadSchema,
  },
);
