import { workflow } from '@novu/framework';
import { z } from 'zod';

const payloadSchema = z.object({
  orderNo: z.string().describe('订单编号'),
  reason: z.string().describe('失败原因'),
  deviceToken: z.string().describe('设备Token').optional(),
  url: z.string().describe('跳转地址').optional().default('/order'),
  showBanner: z.boolean().describe('是否展示横幅').optional().default(false),
  bizType: z.string().describe('业务类型').optional().default(''),
});

export const deliveryCancellationFailureWorkflow = workflow(
  'delivery-cancellation-failure-workflow',
  async ({ step, payload }) => {
    await step.inApp(
      'send-delivery-cancellation-failure-notification',
      () => {
        return {
          subject: `#${payload.orderNo} 外卖订单取消配送申请失败`,
          body: `外卖订单#${payload.orderNo} 取消配送申请失败，原因：${payload.reason}`,
          primaryAction: {
            label: '点击查看',
          },
          data: {
            url: payload.url || '/order',
            showBanner: payload.showBanner,
            bizType: payload.bizType,
          },
        };
      },
      {
        controlSchema: z.object({
          content: z.string().default('外卖订单取消配送申请失败通知'),
        }),
      },
    );

    await step.push(
      'send-delivery-cancellation-failure-push',
      () => {
        return {
          subject: '外卖订单取消配送申请失败',
          body: `订单#${payload.orderNo} 取消配送申请失败：${payload.reason}`,
        };
      },
      {
        skip: () => !payload.deviceToken,
      },
    );
  },
  {
    payloadSchema,
  },
);
