import { workflow } from '@novu/framework';
import { z } from 'zod';

const payloadSchema = z.object({
  orderNo: z.string().describe('订单编号'),
  errorInfo: z.string().describe('报错信息'),
  solution: z.string().describe('解决方案'),
  deviceToken: z.string().describe('设备令牌').optional(),
});

export const deliveryFailureWorkflow = workflow(
  'delivery-failure-workflow',
  async ({ step, payload }) => {
    await step.inApp(
      'send-delivery-failure-notification',
      () => {
        return {
          subject: `#${payload.orderNo} 外卖订单配送失败`,
          body: `外卖订单#${payload.orderNo} 配送失败，原因：${payload.errorInfo}，${payload.solution}`,
          primaryAction: {
            label: '点击查看',
          },
          data: {
            url: `/order`,
          },
        };
      },
      {
        controlSchema: z.object({
          content: z.string().default('外卖订单配送失败通知'),
        }),
      },
    );

    await step.push(
      'send-delivery-failure-push',
      () => {
        return {
          subject: '外卖订单配送失败',
          body: `订单#${payload.orderNo} 配送失败：${payload.errorInfo}`,
        };
      },
      {
        skip: () => !payload.deviceToken,
      },
    );
  },
  {
    payloadSchema,
  },
);
