import { workflow } from '@novu/framework';
import { z } from 'zod';

const payloadSchema = z.object({
  inAppSubject: z
    .string()
    .describe('The subject of the notification')
    .default('**Welcome to Rms**'),
  inAppBody: z
    .string()
    .describe('The body of the notification')
    .default('This is an in-app notification powered by Rms.'),
  inAppAvatar: z
    .string()
    .describe('The avatar of the notification')
    .default('https://avatars.githubusercontent.com/u/77433905?s=200&v=4')
    .optional(),
  primaryAction: z
    .object({
      label: z.string().optional(),
      url: z.string().optional(),
    })
    .optional(),
  data: z
    .object({
      url: z.string().optional(),
    })
    .optional(),
});

export const inAppWorkflow = workflow(
  'in-app-workflow',
  async ({ step, payload }) => {
    const resp: any = {
      subject: payload.inAppSubject,
      body: payload.inAppBody,
      avatar: payload.inAppAvatar,
      data: payload.data,
    };

    if (payload.primaryAction?.url || payload.data?.url) {
      // eslint-disable-next-line @typescript-eslint/no-unsafe-member-access
      resp.primaryAction = {
        label: payload?.primaryAction?.label || '查看',
        url: payload?.primaryAction?.url || payload.data?.url,
      };
    }
    // eslint-disable-next-line @typescript-eslint/no-unsafe-return
    await step.inApp('send-in-app', () => resp, {
      controlSchema: z.object({
        content: z
          .string()
          .default('This is your first Novu In-App {{userName}}'),
      }),
    });
  },
  {
    payloadSchema,
  },
);
