import { workflow } from '@novu/framework';
import { z } from 'zod';

const payloadSchema = z.object({
  brandName: z.string().describe('品牌名称'),
  uri: z.string().describe('下载链接'),
});

export const inviteDownloadWorkflow = workflow(
  'invite-download-workflow',
  async ({ step, payload, subscriber }) => {
    const smsSkip = !subscriber.phone && true;
    await step.sms(
      'send-invite-download-sms',
      () => ({
        body: `您好，${payload.brandName}邀请您加入，请点击${payload.uri} 去下载并登录壹向RMS应用。拒收请回复R`,
      }),
      {
        skip: () => smsSkip,
      },
    );

    const emailSkip = !subscriber.email && true;
    await step.email(
      'send-invite-download-email',
      () => ({
        subject: `${payload.brandName}邀请您加入`,
        body: `
          <!DOCTYPE html>
          <html>
            <head>
              <meta charset="UTF-8">
              <style>
                .title {
                  margin: auto;
                  font-size: 24px;
                  font-weight: bold;
                  text-align: center;
                }
                
                .download-btn {
                  display: inline-block;
                  padding: 10px 20px;
                  background-color: #1890ff;
                  color: white;
                  text-decoration: none;
                  border-radius: 4px;
                  margin: 20px 0;
                }
                
                div {
                  margin-bottom: 20px;
                }

                .img {
                  max-width: 200px;
                  display: block;
                  margin: 0 auto;
                }
              </style>
            </head>
            <body>
              <div>
                <img class="img" src="https://eshine-file.eshine.cn/60003/2025-02-07/logo-new.af63196.png" alt="logo" />
              </div>
              <div>
                <strong>您好</strong>，${payload.brandName}邀请您加入
              </div>
              <div>
                <a href="${payload.uri}" class="download-btn">点击下载壹向RMS APP</a>
              </div>
              <div>
                Thanks
              </div>
              <div>
                杭州当堂信息技术有限公司
              </div>
            </body>
          </html>
        `,
      }),
      {
        skip: () => emailSkip,
      },
    );
  },
  {
    payloadSchema,
  },
);
