import { workflow } from '@novu/framework';
import { z } from 'zod';

const payloadSchema = z.object({
  platform: z.string().describe('外卖平台'),
  orderNo: z.string().describe('订单编号'),
  note: z.string().describe('备注内容'),
});

export const orderNoteUpdateWorkflow = workflow(
  'order-note-update-workflow',
  async ({ step, payload }) => {
    // 发送站内通知
    await step.inApp(
      'send-order-note-update-notification',
      () => {
        return {
          subject: `订单备注更新`,
          body: `${payload.platform}订单#${payload.orderNo} 顾客更新了备注：${payload.note}`,
          primaryAction: {
            label: '查看详情',
          },
          data: {
            url: `/order`,
          },
          // // 添加已读后标记为已处理的状态
          // state: 'processed',
        };
      },
      {
        controlSchema: z.object({
          content: z.string().default('订单备注更新提醒通知'),
        }),
      },
    );

    // 发送 App Push 通知
    // await step.push('send-order-note-update-push', () => {
    //   return {
    //     subject: '订单备注更新',
    //     body: `${payload.platform}订单#${payload.orderNo}：${payload.note}`,
    //   };
    // });
  },
  {
    payloadSchema,
  },
);
