import { workflow } from '@novu/framework';
import { z } from 'zod';

const payloadSchema = z.object({
  orderNo: z.string().describe('订单编号'),
  status: z.string().describe('订单状态'),
  details: z.string().describe('订单详情').optional(),
});

export const orderNotificationWorkflow = workflow(
  'order-notification-workflow',
  async ({ step, payload }) => {
    await step.inApp(
      'send-order-notification',
      () => {
        return {
          subject: `订单通知：${payload.status}`,
          body: `您的订单（ID: ${payload.orderNo}）状态更新为：${payload.status}。${payload.details || ''}`,
        };
      },
      {
        controlSchema: z.object({
          content: z.string().default('订单通知：{{status}}'),
        }),
      },
    );
  },
  {
    payloadSchema,
  },
);
