import { workflow } from '@novu/framework';
import { z } from 'zod';

const payloadSchema = z.object({
  employeeName: z.string().describe('员工姓名'),
  url: z.string().describe('跳转地址').optional().default('/menu'),
  showBanner: z.boolean().describe('是否展示横幅').optional().default(false),
  bizType: z.string().describe('业务类型').optional().default(''),
  posDinePayModel: z
    .string()
    .describe('POS点餐支付方式')
    .optional()
    .default(''),
  deviceToken: z.string().optional().describe('设备令牌'),
});

export const posOrderTutorialWorkflow = workflow(
  'pos-order-tutorial-workflow',
  async ({ step, payload }) => {
    // 发送站内通知
    await step.inApp(
      'send-pos-order-tutorial-notification',
      () => {
        return {
          subject: 'POS测试下单的新手引导教学',
          body: `门店员工 [${payload.employeeName}] 发起了一个POS测试下单的新手引导教学任务。是否执行？`,
          primaryAction: {
            label: '执行',
          },
          data: {
            url: payload.url || '/menu',
            showBanner: payload.showBanner,
            bizType: payload.bizType,
            posDinePayModel: payload.posDinePayModel,
          },
        };
      },
      {
        controlSchema: z.object({
          content: z.string().default('POS测试下单通知'),
        }),
      },
    );

    // 发送推送通知
    await step.push(
      'send-pos-order-tutorial-push',
      () => ({
        subject: 'POS测试下单的新手引导教学',
        body: `门店员工 [${payload.employeeName}] 发起了一个POS测试下单的新手引导教学任务。`,
      }),
      // {
      //   skip: () => !payload.deviceToken,
      // },
    );
  },
  {
    payloadSchema,
  },
);
