import { workflow } from '@novu/framework';
import { z } from 'zod';

const payloadSchema = z.object({
  printerName: z.string().describe('打印机名称'),
  errorInfo: z.string().describe('打印机错误信息'),
  solution: z.string().describe('解决方案'),
  deviceToken: z.string().describe('设备令牌').optional(),
  url: z.string().describe('跳转地址').optional().default('/printer'),
  showBanner: z.boolean().describe('是否展示横幅').optional().default(false),
  bizType: z.string().describe('业务类型').optional().default(''),
});

export const printFailureWorkflow = workflow(
  'print-failure-workflow',
  async ({ step, payload }) => {
    // 发送站内通知
    await step.inApp(
      'send-print-failure-notification',
      () => {
        return {
          subject: '小票打印失败',
          body: `打印机 ${payload.printerName} 打印失败，错误信息：${payload.errorInfo}，解决方案：${payload.solution}`,
          primaryAction: {
            label: '查看详情',
          },
          data: {
            url: payload.url || '/printer',
            showBanner: payload.showBanner,
            bizType: payload.bizType,
          },
        };
      },
      {
        controlSchema: z.object({
          content: z.string().default('打印失败提醒通知'),
        }),
      },
    );

    // 发送 App Push 通知
    await step.push(
      'send-print-failure-push',
      () => {
        return {
          subject: '小票打印失败',
          body: `打印机 ${payload.printerName} 打印失败：${payload.errorInfo}`,
        };
      },
      {
        skip: () => !payload.deviceToken,
      },
    );
  },
  {
    payloadSchema,
  },
);
