import { workflow } from '@novu/framework';
import { z } from 'zod';

const payloadSchema = z.object({
  employeeName: z.string().describe('员工姓名'),
  url: z.string().describe('跳转地址').optional().default('/printer'),
  deviceToken: z.string().describe('设备令牌').optional(),
  showBanner: z.boolean().describe('是否展示横幅').optional().default(false),
  bizType: z.string().describe('业务类型').optional().default(''),
});

export const printerConnectionTutorialWorkflow = workflow(
  'printer-connection-tutorial-workflow',
  async ({ step, payload }) => {
    await step.inApp(
      'send-printer-connection-tutorial-notification',
      () => {
        return {
          subject: '连接打印机的新手引导教学',
          body: `门店员工 [${payload.employeeName}] 发起了一个连接打印机的新手引导教学任务。是否执行？`,
          primaryAction: {
            label: '执行',
          },
          data: {
            showBanner: payload.showBanner,
            url: payload.url || '/printer',
            bizType: payload.bizType,
          },
        };
      },
      {
        controlSchema: z.object({
          content: z.string().default('连接打印机通知'),
        }),
      },
    );

    // 发送 App Push 通知
    await step.push(
      'send-printer-connection-tutorial-push',
      () => {
        return {
          subject: '连接打印机的新手引导教学',
          body: `门店员工 [${payload.employeeName}] 发起了一个连接打印机的新手引导教学任务。是否执行？`,
        };
      },
      // {
      //   skip: () => !payload.deviceToken,
      // },
    );
  },
  {
    payloadSchema,
  },
);
