import { workflow } from '@novu/framework';
import { z } from 'zod';

const payloadSchema = z.object({
  platform: z.string().describe('外卖平台'),
  orderNo: z.string().describe('订单编号'),
  amount: z.number().describe('退款金额'),
  bizType: z.string().describe('业务类型').optional().default(''),
  showBanner: z.boolean().describe('是否展示横幅').optional().default(false),
  url: z.string().describe('跳转地址').optional().default('/order'),
  outOrderNoNo: z.string().describe('外部订单编号').optional().default(''),
});

export const refundRequestWorkflow = workflow(
  'refund-request-workflow',
  async ({ step, payload }) => {
    await step.inApp(
      'send-refund-request-notification',
      () => {
        return {
          subject: `退款申请`,
          body: `${payload.platform}订单#${payload.outOrderNoNo} 顾客提交了退款申请¥${payload.amount}`,
          primaryAction: {
            label: '查看详情',
          },
          data: {
            url: payload.url || '/order',
            bizType: payload.bizType,
            showBanner: payload.showBanner,
            orderNo: payload.orderNo,
            outOrderNoNo: payload.outOrderNoNo,
          },
        };
      },
      {
        controlSchema: z.object({
          content: z.string().default('退款申请提醒通知'),
        }),
      },
    );
  },
  {
    payloadSchema,
  },
);
