import { workflow } from '@novu/framework';
import { z } from 'zod';

const payloadSchema = z.object({
  moduleName: z.string().describe('模块名称'),
  status: z.string().describe('状态'),
  daysLeft: z.number().optional().describe('剩余天数'),
  deviceToken: z.string().describe('设备令牌').optional(),
});

export const renewalReminderWorkflow = workflow(
  'renewal-reminder-workflow',
  async ({ step, payload }) => {
    const subject =
      payload.status === '已到期'
        ? '授权已到期，请尽快续费'
        : '授权即将到期，请尽快续费';
    const body =
      payload.status === '已到期'
        ? `以下门店授权模块已经到期：\n【${payload.moduleName}】 已过期\n为了不影响点单，请尽快前往续费。`
        : `以下门店授权模块即将到期：\n【${payload.moduleName}】 ${payload.daysLeft}天后过期\n为了不影响点单，请尽快前往续费。`;

    // 发送站内通知
    await step.inApp(
      'send-renewal-reminder',
      () => {
        return {
          subject,
          body,
          primaryAction: {
            label: '去续费',
          },
          data: {
            url: '/settings/license',
          },
        };
      },
      {
        controlSchema: z.object({
          content: z.string().default('授权续费提醒通知'),
        }),
      },
    );

    // 发送 App Push 通知
    await step.push(
      'send-renewal-reminder-push',
      () => {
        const pushBody =
          payload.status === '已到期'
            ? `【${payload.moduleName}】已过期，请尽快续费`
            : `【${payload.moduleName}】将在${payload.daysLeft}天后过期`;
        return {
          subject,
          body: pushBody,
        };
      },
      {
        skip: () => !payload.deviceToken,
      },
    );
  },
  {
    payloadSchema,
  },
);
