import { workflow } from '@novu/framework';
import { z } from 'zod';

const payloadSchema = z.object({
  reportName: z.string().describe('报表名称'),
  uri: z.string().describe('下载链接'),
});

export const reportDownloadWorkflow = workflow(
  'report-download-workflow',
  async ({ step, payload }) => {
    await step.email('send-report-download-email', () => ({
      subject: `${payload.reportName}报表下载`,
      body: `
          <!DOCTYPE html>
          <html lang="zh-CN">
            <head>
              <meta charset="UTF-8">
              <meta name="viewport" content="width=device-width, initial-scale=1.0">
              <title>邮件模板</title>
              <style>
                body {
                  font-family: Arial, sans-serif;
                  padding: 20px;
                }
                .logo {
                  text-align: center;
                  margin-bottom: 20px;
                }
                .content {
                  padding: 20px;
                  border-radius: 8px;
                }
              </style>
            </head>
            <body>
              <div class="logo">
                <img alt="Logo" width="100%" src="https://eshine-file.eshine.cn/60003/2025-02-07/logo-new.af63196.png"/>
              </div>
              <div class="content">
                <p>Hi 您好，</p>
                <p><a href="${payload.uri}">此链接</a>是您的【${payload.reportName}】报表，请查收。</p>
                <p>杭州当堂信息技术有限公司</p>
              </div>
            </body>
          </html>
        `,
    }));
  },
  {
    payloadSchema,
  },
);
