import { workflow } from '@novu/framework';
import { z } from 'zod';

// 定义输入参数的验证schema
const payloadSchema = z.object({
  code: z.string().describe('验证码'),
  expire: z.number().describe('过期时间').optional(),
});

export const sendCodeWorkflow = workflow(
  'send-code-workflow',
  async ({ step, payload, subscriber }) => {
    // 验证并解析输入参数
    // 如果有手机号，发送短信
    await step.sms(
      'send-code-sms',
      () => ({
        body: `您的验证码是：${payload.code}，${payload.expire || 5}分钟内有效。`,
      }),
      {
        skip: () => !subscriber.phone,
      },
    );

    // 如果有邮箱，发送邮件
    await step.email(
      'send-code-email',
      () => ({
        subject: '验证码',
        body: `
          <!DOCTYPE html>
          <html>
            <head>
              <meta charset="UTF-8">
              <style>
                .title {
                  margin: auto;
                  font-size: 24px;
                  font-weight: bold;
                  text-align: center;
                }
                
                .code {
                  display: flex;
                  align-items: center;
                  justify-content: center;
                  font-size: 20px;
                  font-weight: bold;
                }
                
                div {
                  margin-bottom: 20px;
                }

                .img {
                  max-width: 200px;
                  display: block;
                  margin: 0 auto;
                }
              </style>
            </head>
            <body>
              <div>
                <img class="img" src="https://eshine-file.eshine.cn/60003/2025-02-07/logo-new.af63196.png" alt="logo" />
              </div>
              <div>
                <strong>Hi</strong>，这是您的验证码
              </div>
              <div>
                ${payload.expire || 5}分钟有效
              </div>
              <div class="code">
                ${payload.code}
              </div>
              <div>
                Thanks
              </div>
              <div>
                杭州当堂信息技术有限公司
              </div>
            </body>
          </html>
        `,
      }),
      {
        skip: () => !subscriber.email,
      },
    );
  },
  {
    payloadSchema,
  },
);
