import { workflow } from '@novu/framework';
import { z } from 'zod';

const payloadSchema = z.object({
  code: z.string().describe('员工个人码'),
});

export const sendStaffCodeWorkflow = workflow(
  'send-staff-code-workflow',
  async ({ step, payload, subscriber }) => {
    const smsSkip = !subscriber.phone && true;
    await step.sms(
      'send-staff-code-sms',
      () => ({
        body: `您的员工个人码为：${payload.code}，个人码用于点单设备登陆和后台公用设备登陆，请妥善保管好个人码。`,
      }),
      {
        skip: () => smsSkip,
      },
    );

    const emailSkip = !subscriber.email && true;
    await step.email(
      'send-staff-code-email',
      () => ({
        subject: '员工个人码',
        body: `
          <!DOCTYPE html>
          <html>
            <head>
              <meta charset="UTF-8">
              <style>
                .title {
                  margin: auto;
                  font-size: 24px;
                  font-weight: bold;
                  text-align: center;
                }
                
                .code {
                  display: flex;
                  align-items: center;
                  justify-content: center;
                  font-size: 20px;
                  font-weight: bold;
                  margin: 20px 0;
                }
                
                div {
                  margin-bottom: 20px;
                }

                .img {
                  max-width: 200px;
                  display: block;
                  margin: 0 auto;
                }
              </style>
            </head>
            <body>
              <div>
                <img class="img" src="https://eshine-file.eshine.cn/60003/2025-02-07/logo-new.af63196.png" alt="logo" />
              </div>
              <div>
                <strong>Hi</strong>，这是您的员工个人码
              </div>
              <div class="code">
                ${payload.code}
              </div>
              <div>
                个人码用于点单设备登陆和后台公用设备登陆，请妥善保管。
              </div>
              <div>
                Thanks
              </div>
              <div>
                杭州当堂信息技术有限公司
              </div>
            </body>
          </html>
        `,
      }),
      {
        skip: () => emailSkip,
      },
    );
  },
  {
    payloadSchema,
  },
);
