import { workflow } from '@novu/framework';
import { z } from 'zod';

const payloadSchema = z.object({
  brand: z.string().describe('品牌'),
  orderCount: z.number().describe('订单数量'),
  deviceToken: z.string().describe('设备令牌').optional(),
});

// 老的 ruleId 15,  template 18
export const supplyChainArrivalReminderWorkflow = workflow(
  'supply-chain-arrival-reminder-workflow',
  async ({ step, payload }) => {
    await step.inApp(
      'send-supply-chain-arrival-reminder',
      () => {
        return {
          subject: '到货提醒',
          body: `【${payload.brand}】您有${payload.orderCount}笔订货单今日，点击此消息查看详情。`,
          primaryAction: {
            label: '点击查看',
          },
          data: {
            url: `/supply/order?date=${new Date(new Date().getTime() + 8 * 60 * 60 * 1000).toISOString().split('T')[0]}`,
          },
        };
      },
      {
        controlSchema: z.object({
          content: z.string().default('到货提醒通知'),
        }),
      },
    );

    await step.push(
      'send-supply-chain-arrival-push',
      () => {
        return {
          subject: '到货提醒',
          body: `【${payload.brand}】您有${payload.orderCount}笔订货单今日到货。`,
        };
      },
      {
        skip: () => !payload.deviceToken,
      },
    );
  },
  {
    payloadSchema,
  },
);
