import { workflow } from '@novu/framework';
import { z } from 'zod';

const payloadSchema = z.object({
  brand: z.string().describe('品牌'),
  orderId: z.string().describe('订单ID').optional(),
  orderCount: z.number().describe('订单数量').default(1),
  deviceToken: z.string().describe('设备令牌').optional(),
});

// 老的 ruleId 11,  template 14
export const supplyChainOrderReminderWorkflow = workflow(
  'supply-chain-order-reminder-workflow',
  async ({ step, payload }) => {
    // 发送站内通知
    await step.inApp(
      'send-supply-chain-order-reminder',
      () => {
        return {
          subject: '预订单发送提醒',
          body: `【${payload.brand}】您有${payload.orderCount}笔预订单需要手动操作发送，请确认后及时发送，以免耽误货品到货时间，点击此消息去发送。`,
          primaryAction: {
            label: '去发送',
          },
          data: {
            orderId: payload.orderId,
            url: `/supply/order?date=${new Date(new Date().getTime() + 8 * 60 * 60 * 1000).toISOString().split('T')[0]}`,
          },
        };
      },
      {
        controlSchema: z.object({
          content: z.string().default('供应链订货提醒通知'),
        }),
      },
    );

    // 发送 App Push 通知
    await step.push(
      'send-supply-chain-order-push',
      () => {
        return {
          subject: '预订单发送提醒',
          body: `【${payload.brand}】您有${payload.orderCount}笔预订单需要手动操作发送，请及时处理。`,
        };
      },
      {
        skip: () => !payload.deviceToken,
      },
    );
  },
  {
    payloadSchema,
  },
);
