import { workflow } from '@novu/framework';
import { z } from 'zod';

const payloadSchema = z.object({
  brand: z.string().describe('品牌'),
  orderId: z.string().describe('订单ID'),
  orderCount: z.number().describe('订单数量'),
  deviceToken: z.string().describe('设备令牌').optional(),
  name: z.string().describe('订货人姓名').optional(),
  url: z.string().describe('订货单链接').optional(),
});

// 老的 ruleId 13,  template 16
export const supplyChainOrderSentSuccessReminderWorkflow = workflow(
  'supply-chain-order-sent-success-reminder-workflow',
  async ({ step, payload, subscriber, controls }) => {
    console.log(
      'supply-chain-order-sent-success-reminder-workflow controls',
      controls,
    );
    // 发送站内通知
    await step.inApp(
      'send-supply-chain-order-sent-success-reminder',
      () => {
        return {
          subject: '订单发送成功提醒',
          body: `【${payload.brand || payload.name}】您有${payload.orderCount}笔订货单发送成功，点击此消息查看详情。`,
          primaryAction: {
            label: '查看详情',
          },
          data: {
            orderId: payload.orderId,
            url: '/supply/order/detail?id=' + payload.orderId,
          },
        };
      },
      {
        controlSchema: z.object({
          content: z.string().default('订货单发送成功通知'),
        }),
      },
    );

    // 发送 App Push 通知
    await step.push(
      'send-supply-chain-order-sent-success-push',
      () => {
        return {
          subject: '订单发送成功提醒',
          body: `【${payload.brand || payload.name}】您有${payload.orderCount}笔订货单发送成功。`,
        };
      },
      // {
      //   skip: () => !payload.deviceToken,
      // },
    );

    await step.sms(
      'send-supply-chain-order-sms',
      () => ({
        body: `hello，${payload.brand || payload.name}来订货了，请安排送货。谢谢。点击链接查看订货单：${payload.url}`,
      }),
      {
        skip: () => !subscriber.phone || !payload.url,
      },
    );

    // 发送邮件通知
    await step.email(
      'send-supply-chain-order-email',
      () => ({
        subject: '新订货通知',
        body: `
          <!DOCTYPE html>
          <html>
            <head>
              <meta charset="UTF-8">
              <style>
                body {
                  font-family: Arial, sans-serif;
                  padding: 20px;
                }
                .content {
                  margin: 20px 0;
                }
                .link {
                  color: #1890ff;
                  text-decoration: none;
                }
              </style>
            </head>
            <body>
              <div class="content">
                hello，${payload.brand || payload.name}来订货了，请安排送货。谢谢。
              </div>
              <div>
                <a href="${payload.url}" class="link">点击查看订货单</a>
              </div>
            </body>
          </html>
        `,
      }),
      {
        skip: () => !subscriber.email || !payload.url,
      },
    );
  },
  {
    payloadSchema,
  },
);
