import { workflow } from '@novu/framework';
import { z } from 'zod';

const payloadSchema = z.object({
  name: z.string().describe('订货人姓名'),
  url: z.string().describe('订货单链接'),
});

export const supplyOrderNotificationWorkflow = workflow(
  'supply-order-notification-workflow',
  async ({ step, payload }) => {
    // 发送短信通知
    await step.sms('send-supply-order-sms', () => ({
      body: `hello，${payload.name}来订货了，请安排送货。谢谢。点击链接查看订货单：${payload.url}`,
    }));

    // 发送邮件通知
    await step.email('send-supply-order-email', () => ({
      subject: '新订货通知',
      body: `
          <!DOCTYPE html>
          <html>
            <head>
              <meta charset="UTF-8">
              <style>
                body {
                  font-family: Arial, sans-serif;
                  padding: 20px;
                }
                .content {
                  margin: 20px 0;
                }
                .link {
                  color: #1890ff;
                  text-decoration: none;
                }
              </style>
            </head>
            <body>
              <div class="content">
                hello，${payload.name}来订货了，请安排送货。谢谢。
              </div>
              <div>
                <a href="${payload.url}" class="link">点击查看订货单</a>
              </div>
            </body>
          </html>
        `,
    }));
  },
  {
    payloadSchema,
  },
);
