import { workflow } from '@novu/framework';
import { z } from 'zod';

const payloadSchema = z.object({
  platform: z.string().describe('外卖平台'),
  itemCount: z.number().describe('未关联餐品数量'),
  storeId: z.string().describe('门店ID'),
  deviceToken: z.string().describe('设备令牌').optional(),
});

export const unlinkedTakeawayItemsWorkflow = workflow(
  'unlinked-takeaway-items-workflow',
  async ({ step, payload }) => {
    // 发送站内通知
    await step.inApp(
      'send-unlinked-takeaway-items-notification',
      () => {
        return {
          subject: '外卖餐品未关联',
          body: `有${payload.itemCount}个${payload.platform}外卖餐品未关联，请前往处理`,
          primaryAction: {
            label: '去处理',
          },
          data: {
            url: `/store/${payload.storeId}/takeaway/items/unlinked`,
          },
          // 添加状态标记，关联后变为已处理
          state: 'processed',
        };
      },
      {
        controlSchema: z.object({
          content: z.string().default('外卖餐品未关联提醒通知'),
        }),
      },
    );

    // 发送 App Push 通知
    await step.push(
      'send-unlinked-takeaway-items-push',
      () => {
        return {
          subject: '外卖餐品未关联',
          body: `${payload.platform}有${payload.itemCount}个餐品未关联，请及时处理`,
        };
      },
      {
        skip: () => !payload.deviceToken,
      },
    );
  },
  {
    payloadSchema,
  },
);
