import { workflow } from '@novu/framework';
import { z } from 'zod';

const payloadSchema = z.object({
  link: z.string().describe('点击链接'),
  deviceToken: z.string().describe('设备令牌').optional(),
});

export const wechatMiniappApprovalWorkflow = workflow(
  'wechat-miniapp-approval-workflow',
  async ({ step, payload }) => {
    // 发送站内通知
    await step.inApp(
      'send-wechat-miniapp-approval-notification',
      () => {
        return {
          subject: '微信小程序审核成功',
          body: `微信小程序审核成功，现在可以正常点单。`,
          primaryAction: {
            label: '点击查看',
          },
          data: {
            link: payload.link,
          },
        };
      },
      {
        controlSchema: z.object({
          content: z.string().default('微信小程序审核成功通知'),
        }),
      },
    );

    // 发送 App Push 通知
    await step.push(
      'send-wechat-miniapp-approval-push',
      () => {
        return {
          subject: '微信小程序审核成功',
          body: `微信小程序审核成功，现在可以正常点单。`,
        };
      },
      {
        skip: () => !payload.deviceToken,
      },
    );
  },
  {
    payloadSchema,
  },
);
