import { workflow } from '@novu/framework';
import { z } from 'zod';

const payloadSchema = z
  .object({
    accessToken: z.string().optional().describe('微信 access_token'),
    touser: z.string().describe('微信用户 openid'),
    templateId: z
      .string()
      .optional()
      .describe('微信模板 id')
      .default('CNTIq__V-7Y5_0MjgDklXx4gDhhtXkuaYEvX8XLwdzA'),
    page: z.string().optional().describe('微信模板跳转页面路径'),
    miniprogramState: z.string().optional().describe('微信模板跳转小程序状态'),
    lang: z.string().optional().describe('微信模板语言').default('zh_CN'),
    orderNo: z.string().describe('订单号').optional(),
    character_string22: z.string().describe('订单号').optional(),
    productDetails: z.string().describe('餐品详情').optional(),
    thing11: z.string().describe('餐品详情').optional(),
    storeName: z.string().describe('门店名称').optional(),
    thing23: z.string().describe('门店名称').optional(),
    pickupLocation: z.string().describe('取餐地点').optional(),
    thing10: z.string().describe('取餐地点').optional(),
    reminder: z
      .string()
      .describe('温馨提醒')
      .default('您的餐品已制作完成，请到前台领取')
      .optional(),
    thing7: z
      .string()
      .describe('温馨提醒')
      .optional()
      .default('您的餐品已制作完成，请到前台领取'),
    brandId: z.number().describe('品牌 id'),
  })
  .refine((data) => data.accessToken || data.brandId, {
    message: 'accessToken 和 brandId 必须至少提供一个',
  });

export const wechatPickupNotificationWorkflow = workflow(
  'wechat-pickup-notification-workflow',
  async ({ step, payload }) => {
    await step.chat('send-wechat-pickup-notification', () => {
      return {
        body: JSON.stringify({
          access_token: payload.accessToken,
          touser: payload.touser,
          template_id:
            payload?.templateId ||
            'CNTIq__V-7Y5_0MjgDklXx4gDhhtXkuaYEvX8XLwdzA',
          page: payload?.page || '',
          data: {
            character_string22: {
              value: payload.orderNo || payload?.character_string22 || '订单号',
            },
            thing11: {
              value: payload?.productDetails || payload?.thing11 || '餐品详情',
            },
            thing23: {
              value: payload?.storeName || payload?.thing23 || '门店名称',
            },
            thing10: {
              value: payload?.pickupLocation || payload?.thing10 || '取餐地点',
            },
            thing7: {
              value:
                payload?.reminder ||
                payload?.thing7 ||
                '您的餐品已制作完成，请到前台领取',
            },
          },
          miniprogram_state: payload?.miniprogramState || 'formal',
          lang: payload?.lang || 'zh_CN',
          webhookBody: {
            brandId: payload?.brandId,
            authType: '2',
          },
        }),
      };
    });
  },
  {
    payloadSchema,
  },
);
